@@ -1,5 +1,5 @@
 
-/* $Id: impl-eazelproxy.c,v 1.58 2000/10/23 15:36:28 mfleming Exp $
+/* $Id: impl-eazelproxy.c,v 1.60 2000/11/01 23:15:53 mfleming Exp $
  * 
  * Copyright (C) 2000 Eazel, Inc
  *
@@ -943,6 +943,7 @@ user_proxy_request_cb (gpointer user_data, unsigned short port, HTTPRequest *req
 
 	*p_header_list = g_list_remove_all_custom (*p_header_list, "Authorization: ", util_glist_string_starts_with);
 
+	/* FIXME mfleming we can remove this now */
 	/* Smack Mozilla User-Agent string (We have a problem setting the optional field in M18 */
 
 	user_agent_node = g_list_find_custom (*p_header_list, "User-Agent: Mozilla", util_glist_string_starts_with);
@@ -1631,7 +1632,12 @@ impl_EazelProxy_UserControl_prompt_authenticate_user (
 			 * then the user was supposed to have specified one via
 			 * the prompt
 			 */
-			if ( '\0' == user->user.user_name[0] ) {
+			/* robey 27oct2000: let the user override the username always */
+			/* if ( '\0' == user->user.user_name[0] ) {
+				CORBA_free (user->user.user_name);
+				user->user.user_name = CORBA_string_dup (new_authninfo->username);
+				} */
+			if (new_authninfo->username[0] != '\0') {
 				CORBA_free (user->user.user_name);
 				user->user.user_name = CORBA_string_dup (new_authninfo->username);
 			}
