@@ -1,4 +1,4 @@
-/* $Id: request.c,v 1.38 2000/10/30 21:08:40 mfleming Exp $
+/* $Id: request.c,v 1.39 2000/11/01 23:15:53 mfleming Exp $
  *
  * Handles incoming request callbacks, buffers headers, and passes
  * the request on to the upstream server.
@@ -743,6 +743,9 @@ proxy_do_connect(Socket *client_sock)
 		}
 	}
 
+	/* Add "Connection: close" (proxy_get_headers has removed any Connection headers( */
+	conn->header_list_request = g_list_prepend (conn->header_list_request, g_strdup ("Connection: close"));
+
 	/* Force the HTTP version to 1.0 */
 	u_replace_string (&(conn->request->version), g_strdup("1.0")); 
 
@@ -840,6 +843,17 @@ proxy_get_headers(Socket *sock)
 				line = NULL;
 				continue;
 			}
+
+			if (STRING_STARTS_WITH (line, "Connection:")) {
+				/* remove any "Connection:" lines
+				 * so that HTTP/1.1 clients/servers don't try
+				 * to use persistant connections
+				 */
+				g_free (line);
+				line = NULL;
+				continue;
+			}
+
 			conn->header_list_request = g_list_append (conn->header_list_request, line); 
 			line = NULL;
 		}
